..
    Copyright (C) 2021 Graz University of Technology.

    invenio-imoox is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

===============
 invenio-imoox
===============

.. image:: https://github.com/tu-graz-library/invenio-imoox/workflows/CI/badge.svg
        :target: https://github.com/tu-graz-library/invenio-imoox/actions?query=workflow%3ACI

.. image:: https://img.shields.io/github/tag/tu-graz-library/invenio-imoox.svg
        :target: https://github.com/tu-graz-library/invenio-imoox/releases

.. image:: https://img.shields.io/pypi/dm/invenio-imoox.svg
        :target: https://pypi.python.org/pypi/invenio-imoox

.. image:: https://img.shields.io/github/license/tu-graz-library/invenio-imoox.svg
        :target: https://github.com/tu-graz-library/invenio-imoox/blob/master/LICENSE

Provides API for iMooX.

Further documentation is available on
https://invenio-imoox.readthedocs.io/
